package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.ImageServicesMapper;
import com.zyc.system.domain.ImageServices;
import com.zyc.system.service.IImageServicesService;

/**
 * 镜像服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class ImageServicesServiceImpl implements IImageServicesService 
{
    @Autowired
    private ImageServicesMapper imageServicesMapper;

    /**
     * 查询镜像服务
     * 
     * @param id 镜像服务主键
     * @return 镜像服务
     */
    @Override
    public ImageServices selectImageServicesById(Integer id)
    {
        return imageServicesMapper.selectImageServicesById(id);
    }

    /**
     * 查询镜像服务列表
     * 
     * @param imageServices 镜像服务
     * @return 镜像服务
     */
    @Override
    public List<ImageServices> selectImageServicesList(ImageServices imageServices)
    {
        return imageServicesMapper.selectImageServicesList(imageServices);
    }

    /**
     * 新增镜像服务
     * 
     * @param imageServices 镜像服务
     * @return 结果
     */
    @Override
    public int insertImageServices(ImageServices imageServices)
    {
        return imageServicesMapper.insertImageServices(imageServices);
    }

    /**
     * 修改镜像服务
     * 
     * @param imageServices 镜像服务
     * @return 结果
     */
    @Override
    public int updateImageServices(ImageServices imageServices)
    {
        return imageServicesMapper.updateImageServices(imageServices);
    }

    /**
     * 批量删除镜像服务
     * 
     * @param ids 需要删除的镜像服务主键
     * @return 结果
     */
    @Override
    public int deleteImageServicesByIds(Integer[] ids)
    {
        return imageServicesMapper.deleteImageServicesByIds(ids);
    }

    /**
     * 删除镜像服务信息
     * 
     * @param id 镜像服务主键
     * @return 结果
     */
    @Override
    public int deleteImageServicesById(Integer id)
    {
        return imageServicesMapper.deleteImageServicesById(id);
    }
}
